==> tellico_0.13.3.orig.tar.gz: tellico-0.13.3/src/fetch/configwidget.h <==
/***************************************************************************
    copyright            : (C) 2003-2004 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef FETCHCONFIGWIDGET_H
#define FETCHCONFIGWIDGET_H

class KConfig;

#include "fetch.h"

#include <qwidget.h>

namespace Tellico {
  namespace Fetch {

/**
 * @author Robby Stephenson
 * @version $Id: configdialog.h 911 2004-10-06 00:53:40Z robby $
 */
class ConfigWidget : public QWidget {
Q_OBJECT

public:
  ConfigWidget(QWidget* parent_) : QWidget(parent_), m_modified(false), m_accepted(false) {}
  virtual ~ConfigWidget() {}

  void setAccepted(bool accepted_) { m_accepted = accepted_; }
  bool shouldSave() const { return m_modified && m_accepted; }
  /**
   * Read any configuration options. The config group must be
   * set before calling this function.
   *
   * @param config_ The KConfig pointer
   */
//  virtual void readConfig(KConfig* config_) = 0;
  /**
   * Saves any configuration options. The config group must be
   * set before calling this function.
   *
   * @param config_ The KConfig pointer
   */
  virtual void saveConfig(KConfig* config_) = 0;

public slots:
  void slotSetModified(bool modified_ = true) { m_modified = modified_; }

private:
  bool m_modified;
  bool m_accepted;
};

  }
}

#endif

==> tellico-1.1.5.tar.gz: tellico-1.1.5/src/fetch/configwidget.h <==
/***************************************************************************
    copyright            : (C) 2003-2006 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef FETCHCONFIGWIDGET_H
#define FETCHCONFIGWIDGET_H

class KConfig;
class QCheckBox;

#include "fetch.h"
#include "../datavectors.h"

#include <qwidget.h>
#include <qdict.h>
#include <qcheckbox.h>

namespace Tellico {
  namespace Fetch {

/**
 * @author Robby Stephenson
 */
class ConfigWidget : public QWidget {
Q_OBJECT

public:
  ConfigWidget(QWidget* parent);
  virtual ~ConfigWidget() {}

  void setAccepted(bool accepted_) { m_accepted = accepted_; }
  bool shouldSave() const { return m_modified && m_accepted; }
  /**
   * Saves any configuration options. The config group must be
   * set before calling this function.
   *
   * @param config_ The KConfig pointer
   */
  virtual void saveConfig(KConfig* config) = 0;

public slots:
  void slotSetModified(bool modified_ = true) { m_modified = modified_; }

protected:
  QWidget* optionsWidget() { return m_optionsWidget; }
  void addFieldsWidget(const StringMap& customFields, const QStringList& fieldsToAdd);
  void saveFieldsConfig(KConfig* config) const;

private:
  bool m_modified;
  bool m_accepted;
  QWidget* m_optionsWidget;
  QDict<QCheckBox> m_fields;
};

  }
}

#endif
